Commit in GeomConverter/test/org/lcsim/material on MAIN
BetheBlockTest.java+21-101.4 -> 1.5
 CM: change pT reserved for p_Transverse- 2 components- to p input (GeV)

GeomConverter/test/org/lcsim/material
BetheBlockTest.java 1.4 -> 1.5
diff -u -r1.4 -r1.5
--- BetheBlockTest.java	18 Jan 2006 23:24:37 -0000	1.4
+++ BetheBlockTest.java	21 Jan 2006 18:28:02 -0000	1.5
@@ -38,13 +38,15 @@
         MaterialElement element = new MaterialElement("DummyElement", 1.0, 1.0);
         Material material = new Material("DummyMaterial", 1, 1.0, org.lcsim.material.MaterialState.SOLID, 1.0, 1.0);
         material.addElement(element, 1.0);
-        
-        double pT[] = {1.0, 0, 0};
+        /*CarolineMilstene- I replaced pT by p. The reason is that generally we reserve
+	pT for P-Transverse which is (px,py)and has 2 component whereas you define a 3 
+	component momentum []p=(1.,0.,0.)= (px,py,pz) */
+        double p[] = {1.0, 0, 0};
         double mass = 1.0;
         
         double dEdx = MaterialCalculator.computeBetheBloch(
         		material, // material 
-        		pT,       // particle momentum
+        		p,       // particle momentum
         		mass,     // particle mass
         		1.0,      // particle charge
         		1.0);     // path length   
@@ -60,16 +62,25 @@
     	
     	assert(material != null);
     	
-    	double pT[] = {1.0, 0, 0};
+    	double p[] = {1.0, 0, 0};
     	
     	// muon mass in MeV 
     	double mass = 105.658369;
-    	
+    	/* CarolineMilstene- To Jeremy: The Momentum in the package is in
+	(GeV), we deal mostly with particles with masses of ~100 MeV/c
+	which are relativistic, therefore their momentum is of the order
+	of ~(GeV)=1000 MeV, which is also the unit in the pacjage we use,
+	 therefore I make the transformation inside the formula- 
+	 We enter with []p in GeV and inside it becomes []pmev
+	using a factor 1e+03 for each component and the calculation is 
+	made- then beta and gamma is calculated using those factors 
+	Jeremy-you can reduce this comment once you read and hopefully 
+	approve */
     	double dEdx = MaterialCalculator.computeBetheBloch(
-    			material, // material 
-    			pT,       // particle momentum
-    			mass,     // particle mass 
+    			material, // material 			
+    			p,        // particle momentum-in GeV 
+    			mass,     // particle mass -MeV/c
     			1.0,      // particle charge
-    			1.0);     // path length
+    			1.0);     // path length ! (cm)
     }
-}
\ No newline at end of file
+}
CVSspam 0.2.8